diff libpurple/protocols/qq/send_core.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/send_core.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/send_core.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file send_core.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -28,10 +28,10 @@
 #include <glib.h>
 #include "connection.h"
 
-gint qq_send_cmd(GaimConnection *gc, guint16 cmd, gboolean is_auto_seq, guint16 seq, 
+gint qq_send_cmd(PurpleConnection *gc, guint16 cmd, gboolean is_auto_seq, guint16 seq, 
 		gboolean need_ack, guint8 *data, gint len);
-gint _qq_send_packet(GaimConnection * gc, guint8 *buf, gint len, guint16 cmd);
+gint _qq_send_packet(PurpleConnection * gc, guint8 *buf, gint len, guint16 cmd);
 gint _create_packet_head_seq(guint8 *buf, guint8 **cursor,
-		GaimConnection *gc, guint16 cmd, gboolean is_auto_seq, guint16 *seq);
+		PurpleConnection *gc, guint16 cmd, gboolean is_auto_seq, guint16 *seq);
 
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.